# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/lifecycle_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/lifecycle_policy.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8yandex/cloud/containerregistry/v1/lifecycle_policy.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcf\x02\n\x0fLifecyclePolicy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12I\n\x06status\x18\x05 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.LifecyclePolicy.Status\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x05rules\x18\x07 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.LifecycleRule\":\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xbc\x01\n\rLifecycleRule\x12\x1e\n\x0b\x64\x65scription\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12;\n\rexpire_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05>=24h\x12\x1d\n\ntag_regexp\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x10\n\x08untagged\x18\x04 \x01(\x08\x12\x1d\n\x0cretained_top\x18\x05 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_LIFECYCLEPOLICY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=469,
  serialized_end=527,
)
_sym_db.RegisterEnumDescriptor(_LIFECYCLEPOLICY_STATUS)


_LIFECYCLEPOLICY = _descriptor.Descriptor(
  name='LifecyclePolicy',
  full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repository_id', full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy.repository_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='yandex.cloud.containerregistry.v1.LifecyclePolicy.rules', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LIFECYCLEPOLICY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=527,
)


_LIFECYCLERULE = _descriptor.Descriptor(
  name='LifecycleRule',
  full_name='yandex.cloud.containerregistry.v1.LifecycleRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.containerregistry.v1.LifecycleRule.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_period', full_name='yandex.cloud.containerregistry.v1.LifecycleRule.expire_period', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\005>=24h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag_regexp', full_name='yandex.cloud.containerregistry.v1.LifecycleRule.tag_regexp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='untagged', full_name='yandex.cloud.containerregistry.v1.LifecycleRule.untagged', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retained_top', full_name='yandex.cloud.containerregistry.v1.LifecycleRule.retained_top', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=718,
)

_LIFECYCLEPOLICY.fields_by_name['status'].enum_type = _LIFECYCLEPOLICY_STATUS
_LIFECYCLEPOLICY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LIFECYCLEPOLICY.fields_by_name['rules'].message_type = _LIFECYCLERULE
_LIFECYCLEPOLICY_STATUS.containing_type = _LIFECYCLEPOLICY
_LIFECYCLERULE.fields_by_name['expire_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['LifecyclePolicy'] = _LIFECYCLEPOLICY
DESCRIPTOR.message_types_by_name['LifecycleRule'] = _LIFECYCLERULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LifecyclePolicy = _reflection.GeneratedProtocolMessageType('LifecyclePolicy', (_message.Message,), {
  'DESCRIPTOR' : _LIFECYCLEPOLICY,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.LifecyclePolicy)
  })
_sym_db.RegisterMessage(LifecyclePolicy)

LifecycleRule = _reflection.GeneratedProtocolMessageType('LifecycleRule', (_message.Message,), {
  'DESCRIPTOR' : _LIFECYCLERULE,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.LifecycleRule)
  })
_sym_db.RegisterMessage(LifecycleRule)


DESCRIPTOR._options = None
_LIFECYCLERULE.fields_by_name['description']._options = None
_LIFECYCLERULE.fields_by_name['expire_period']._options = None
_LIFECYCLERULE.fields_by_name['tag_regexp']._options = None
_LIFECYCLERULE.fields_by_name['retained_top']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/elasticsearch/v1/auth.proto',
  package='yandex.cloud.mdb.elasticsearch.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,yandex/cloud/mdb/elasticsearch/v1/auth.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1dyandex/cloud/validation.proto\"S\n\rAuthProviders\x12\x42\n\tproviders\x18\x01 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProvider\"\x80\x03\n\x0c\x41uthProvider\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.mdb.elasticsearch.v1.AuthProvider.Type\x12*\n\x04name\x18\x02 \x01(\tB\x1c\x8a\xc8\x31\x04<=50\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x12\r\n\x05order\x18\x03 \x01(\x03\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x0e\n\x06hidden\x18\x05 \x01(\x08\x12\x1d\n\x0b\x64\x65scription\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x17\n\x04hint\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x17\n\x04icon\x18\x08 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12?\n\x04saml\x18\t \x01(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.SamlSettingsH\x00\"2\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x08\n\x04SAML\x10\x02\x42\n\n\x08settings\"\xc8\x02\n\x0cSamlSettings\x12 \n\ridp_entity_id\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12&\n\x11idp_metadata_file\x18\x02 \x01(\x0c\x42\x0b\x8a\xc8\x31\x07<=10000\x12\x1f\n\x0csp_entity_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x1d\n\nkibana_url\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12%\n\x13\x61ttribute_principal\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\"\n\x10\x61ttribute_groups\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12 \n\x0e\x61ttribute_name\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12!\n\x0f\x61ttribute_email\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1e\n\x0c\x61ttribute_dn\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50B|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_AUTHPROVIDER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAML', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=522,
  serialized_end=572,
)
_sym_db.RegisterEnumDescriptor(_AUTHPROVIDER_TYPE)


_AUTHPROVIDERS = _descriptor.Descriptor(
  name='AuthProviders',
  full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProviders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providers', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProviders.providers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=197,
)


_AUTHPROVIDER = _descriptor.Descriptor(
  name='AuthProvider',
  full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50\362\3071\020[a-z][a-z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.order', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.hidden', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.hint', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.icon', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saml', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.saml', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUTHPROVIDER_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='settings', full_name='yandex.cloud.mdb.elasticsearch.v1.AuthProvider.settings',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=200,
  serialized_end=584,
)


_SAMLSETTINGS = _descriptor.Descriptor(
  name='SamlSettings',
  full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idp_entity_id', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.idp_entity_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idp_metadata_file', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.idp_metadata_file', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\007<=10000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_entity_id', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.sp_entity_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kibana_url', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.kibana_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute_principal', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.attribute_principal', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute_groups', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.attribute_groups', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute_name', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.attribute_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute_email', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.attribute_email', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attribute_dn', full_name='yandex.cloud.mdb.elasticsearch.v1.SamlSettings.attribute_dn', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=587,
  serialized_end=915,
)

_AUTHPROVIDERS.fields_by_name['providers'].message_type = _AUTHPROVIDER
_AUTHPROVIDER.fields_by_name['type'].enum_type = _AUTHPROVIDER_TYPE
_AUTHPROVIDER.fields_by_name['saml'].message_type = _SAMLSETTINGS
_AUTHPROVIDER_TYPE.containing_type = _AUTHPROVIDER
_AUTHPROVIDER.oneofs_by_name['settings'].fields.append(
  _AUTHPROVIDER.fields_by_name['saml'])
_AUTHPROVIDER.fields_by_name['saml'].containing_oneof = _AUTHPROVIDER.oneofs_by_name['settings']
DESCRIPTOR.message_types_by_name['AuthProviders'] = _AUTHPROVIDERS
DESCRIPTOR.message_types_by_name['AuthProvider'] = _AUTHPROVIDER
DESCRIPTOR.message_types_by_name['SamlSettings'] = _SAMLSETTINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthProviders = _reflection.GeneratedProtocolMessageType('AuthProviders', (_message.Message,), {
  'DESCRIPTOR' : _AUTHPROVIDERS,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.AuthProviders)
  })
_sym_db.RegisterMessage(AuthProviders)

AuthProvider = _reflection.GeneratedProtocolMessageType('AuthProvider', (_message.Message,), {
  'DESCRIPTOR' : _AUTHPROVIDER,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.AuthProvider)
  })
_sym_db.RegisterMessage(AuthProvider)

SamlSettings = _reflection.GeneratedProtocolMessageType('SamlSettings', (_message.Message,), {
  'DESCRIPTOR' : _SAMLSETTINGS,
  '__module__' : 'yandex.cloud.mdb.elasticsearch.v1.auth_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.elasticsearch.v1.SamlSettings)
  })
_sym_db.RegisterMessage(SamlSettings)


DESCRIPTOR._options = None
_AUTHPROVIDER.fields_by_name['name']._options = None
_AUTHPROVIDER.fields_by_name['description']._options = None
_AUTHPROVIDER.fields_by_name['hint']._options = None
_AUTHPROVIDER.fields_by_name['icon']._options = None
_SAMLSETTINGS.fields_by_name['idp_entity_id']._options = None
_SAMLSETTINGS.fields_by_name['idp_metadata_file']._options = None
_SAMLSETTINGS.fields_by_name['sp_entity_id']._options = None
_SAMLSETTINGS.fields_by_name['kibana_url']._options = None
_SAMLSETTINGS.fields_by_name['attribute_principal']._options = None
_SAMLSETTINGS.fields_by_name['attribute_groups']._options = None
_SAMLSETTINGS.fields_by_name['attribute_name']._options = None
_SAMLSETTINGS.fields_by_name['attribute_email']._options = None
_SAMLSETTINGS.fields_by_name['attribute_dn']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_ingestion_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud.logging.v1 import log_resource_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/logging/v1/log_ingestion_service.proto',
  package='yandex.cloud.logging.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/logging/v1/log_ingestion_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x17google/rpc/status.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a*yandex/cloud/logging/v1/log_resource.proto\x1a\x1dyandex/cloud/validation.proto\"\x90\x02\n\x0cWriteRequest\x12?\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32$.yandex.cloud.logging.v1.DestinationB\x04\xe8\xc7\x31\x01\x12;\n\x08resource\x18\x02 \x01(\x0b\x32).yandex.cloud.logging.v1.LogEntryResource\x12\x45\n\x07\x65ntries\x18\x03 \x03(\x0b\x32).yandex.cloud.logging.v1.IncomingLogEntryB\t\x82\xc8\x31\x05\x31-100\x12;\n\x08\x64\x65\x66\x61ults\x18\x04 \x01(\x0b\x32).yandex.cloud.logging.v1.LogEntryDefaults\"\x96\x01\n\rWriteResponse\x12\x42\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.logging.v1.WriteResponse.ErrorsEntry\x1a\x41\n\x0b\x45rrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status:\x02\x38\x01\x32m\n\x13LogIngestionService\x12V\n\x05Write\x12%.yandex.cloud.logging.v1.WriteRequest\x1a&.yandex.cloud.logging.v1.WriteResponseBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3'
  ,
  dependencies=[google_dot_rpc_dot_status__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_WRITEREQUEST = _descriptor.Descriptor(
  name='WriteRequest',
  full_name='yandex.cloud.logging.v1.WriteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination', full_name='yandex.cloud.logging.v1.WriteRequest.destination', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='yandex.cloud.logging.v1.WriteRequest.resource', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entries', full_name='yandex.cloud.logging.v1.WriteRequest.entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0051-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaults', full_name='yandex.cloud.logging.v1.WriteRequest.defaults', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=494,
)


_WRITERESPONSE_ERRORSENTRY = _descriptor.Descriptor(
  name='ErrorsEntry',
  full_name='yandex.cloud.logging.v1.WriteResponse.ErrorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.WriteResponse.ErrorsEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.WriteResponse.ErrorsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=647,
)

_WRITERESPONSE = _descriptor.Descriptor(
  name='WriteResponse',
  full_name='yandex.cloud.logging.v1.WriteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='yandex.cloud.logging.v1.WriteResponse.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WRITERESPONSE_ERRORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=647,
)

_WRITEREQUEST.fields_by_name['destination'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2._DESTINATION
_WRITEREQUEST.fields_by_name['resource'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2._LOGENTRYRESOURCE
_WRITEREQUEST.fields_by_name['entries'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2._INCOMINGLOGENTRY
_WRITEREQUEST.fields_by_name['defaults'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2._LOGENTRYDEFAULTS
_WRITERESPONSE_ERRORSENTRY.fields_by_name['value'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_WRITERESPONSE_ERRORSENTRY.containing_type = _WRITERESPONSE
_WRITERESPONSE.fields_by_name['errors'].message_type = _WRITERESPONSE_ERRORSENTRY
DESCRIPTOR.message_types_by_name['WriteRequest'] = _WRITEREQUEST
DESCRIPTOR.message_types_by_name['WriteResponse'] = _WRITERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WriteRequest = _reflection.GeneratedProtocolMessageType('WriteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WRITEREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_ingestion_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.WriteRequest)
  })
_sym_db.RegisterMessage(WriteRequest)

WriteResponse = _reflection.GeneratedProtocolMessageType('WriteResponse', (_message.Message,), {

  'ErrorsEntry' : _reflection.GeneratedProtocolMessageType('ErrorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _WRITERESPONSE_ERRORSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.log_ingestion_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.WriteResponse.ErrorsEntry)
    })
  ,
  'DESCRIPTOR' : _WRITERESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_ingestion_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.WriteResponse)
  })
_sym_db.RegisterMessage(WriteResponse)
_sym_db.RegisterMessage(WriteResponse.ErrorsEntry)


DESCRIPTOR._options = None
_WRITEREQUEST.fields_by_name['destination']._options = None
_WRITEREQUEST.fields_by_name['entries']._options = None
_WRITERESPONSE_ERRORSENTRY._options = None

_LOGINGESTIONSERVICE = _descriptor.ServiceDescriptor(
  name='LogIngestionService',
  full_name='yandex.cloud.logging.v1.LogIngestionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=649,
  serialized_end=758,
  methods=[
  _descriptor.MethodDescriptor(
    name='Write',
    full_name='yandex.cloud.logging.v1.LogIngestionService.Write',
    index=0,
    containing_service=None,
    input_type=_WRITEREQUEST,
    output_type=_WRITERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGINGESTIONSERVICE)

DESCRIPTOR.services_by_name['LogIngestionService'] = _LOGINGESTIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/operation/operation_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/operation/operation_service.proto',
  package='yandex.cloud.operation',
  syntax='proto3',
  serialized_options=b'\n\032yandex.cloud.api.operationZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/operation;operation',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.yandex/cloud/operation/operation_service.proto\x12\x16yandex.cloud.operation\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x13GetOperationRequest\x12\x1a\n\x0coperation_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x16\x43\x61ncelOperationRequest\x12\x1a\n\x0coperation_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\x96\x02\n\x10OperationService\x12y\n\x03Get\x12+.yandex.cloud.operation.GetOperationRequest\x1a!.yandex.cloud.operation.Operation\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/operations/{operation_id}\x12\x86\x01\n\x06\x43\x61ncel\x12..yandex.cloud.operation.CancelOperationRequest\x1a!.yandex.cloud.operation.Operation\")\x82\xd3\xe4\x93\x02#\x12!/operations/{operation_id}:cancelBb\n\x1ayandex.cloud.api.operationZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/operation;operationb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETOPERATIONREQUEST = _descriptor.Descriptor(
  name='GetOperationRequest',
  full_name='yandex.cloud.operation.GetOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='yandex.cloud.operation.GetOperationRequest.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=224,
)


_CANCELOPERATIONREQUEST = _descriptor.Descriptor(
  name='CancelOperationRequest',
  full_name='yandex.cloud.operation.CancelOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='yandex.cloud.operation.CancelOperationRequest.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=278,
)

DESCRIPTOR.message_types_by_name['GetOperationRequest'] = _GETOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['CancelOperationRequest'] = _CANCELOPERATIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetOperationRequest = _reflection.GeneratedProtocolMessageType('GetOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOPERATIONREQUEST,
  '__module__' : 'yandex.cloud.operation.operation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.operation.GetOperationRequest)
  })
_sym_db.RegisterMessage(GetOperationRequest)

CancelOperationRequest = _reflection.GeneratedProtocolMessageType('CancelOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELOPERATIONREQUEST,
  '__module__' : 'yandex.cloud.operation.operation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.operation.CancelOperationRequest)
  })
_sym_db.RegisterMessage(CancelOperationRequest)


DESCRIPTOR._options = None
_GETOPERATIONREQUEST.fields_by_name['operation_id']._options = None
_CANCELOPERATIONREQUEST.fields_by_name['operation_id']._options = None

_OPERATIONSERVICE = _descriptor.ServiceDescriptor(
  name='OperationService',
  full_name='yandex.cloud.operation.OperationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=281,
  serialized_end=559,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.operation.OperationService.Get',
    index=0,
    containing_service=None,
    input_type=_GETOPERATIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\034\022\032/operations/{operation_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Cancel',
    full_name='yandex.cloud.operation.OperationService.Cancel',
    index=1,
    containing_service=None,
    input_type=_CANCELOPERATIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002#\022!/operations/{operation_id}:cancel',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPERATIONSERVICE)

DESCRIPTOR.services_by_name['OperationService'] = _OPERATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/saml/federation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/organizationmanager/v1/saml/federation.proto',
  package='yandex.cloud.organizationmanager.v1.saml',
  syntax='proto3',
  serialized_options=b'\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;saml',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9yandex/cloud/organizationmanager/v1/saml/federation.proto\x12(yandex.cloud.organizationmanager.v1.saml\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xbc\x05\n\nFederation\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x33\n\x04name\x18\x03 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x0e\x63ookie_max_age\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31\x30m-12h\x12$\n\x1c\x61uto_create_account_on_login\x18\x07 \x01(\x08\x12\x1e\n\x06issuer\x18\x08 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12J\n\x0bsso_binding\x18\t \x01(\x0e\x32\x35.yandex.cloud.organizationmanager.v1.saml.BindingType\x12\x1f\n\x07sso_url\x18\n \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12_\n\x11security_settings\x18\x0b \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings\x12!\n\x19\x63\x61se_insensitive_name_ids\x18\x0c \x01(\x08\x12P\n\x06labels\x18\r \x03(\x0b\x32@.yandex.cloud.organizationmanager.v1.saml.Federation.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1a\x46\x65\x64\x65rationSecuritySettings\x12\x1c\n\x14\x65ncrypted_assertions\x18\x01 \x01(\x08*Q\n\x0b\x42indingType\x12\x1c\n\x18\x42INDING_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04POST\x10\x01\x12\x0c\n\x08REDIRECT\x10\x02\x12\x0c\n\x08\x41RTIFACT\x10\x03\x42\x81\x01\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;samlb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_BINDINGTYPE = _descriptor.EnumDescriptor(
  name='BindingType',
  full_name='yandex.cloud.organizationmanager.v1.saml.BindingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BINDING_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDIRECT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARTIFACT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=962,
  serialized_end=1043,
)
_sym_db.RegisterEnumDescriptor(_BINDINGTYPE)

BindingType = enum_type_wrapper.EnumTypeWrapper(_BINDINGTYPE)
BINDING_TYPE_UNSPECIFIED = 0
POST = 1
REDIRECT = 2
ARTIFACT = 3



_FEDERATION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.organizationmanager.v1.saml.Federation.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=900,
)

_FEDERATION = _descriptor.Descriptor(
  name='Federation',
  full_name='yandex.cloud.organizationmanager.v1.saml.Federation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.organization_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.created_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie_max_age', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.cookie_max_age', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\00710m-12h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_create_account_on_login', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.auto_create_account_on_login', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuer', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.issuer', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=8000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sso_binding', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.sso_binding', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sso_url', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.sso_url', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=8000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_settings', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.security_settings', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_insensitive_name_ids', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.case_insensitive_name_ids', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.organizationmanager.v1.saml.Federation.labels', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEDERATION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=900,
)


_FEDERATIONSECURITYSETTINGS = _descriptor.Descriptor(
  name='FederationSecuritySettings',
  full_name='yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encrypted_assertions', full_name='yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings.encrypted_assertions', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=960,
)

_FEDERATION_LABELSENTRY.containing_type = _FEDERATION
_FEDERATION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEDERATION.fields_by_name['cookie_max_age'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEDERATION.fields_by_name['sso_binding'].enum_type = _BINDINGTYPE
_FEDERATION.fields_by_name['security_settings'].message_type = _FEDERATIONSECURITYSETTINGS
_FEDERATION.fields_by_name['labels'].message_type = _FEDERATION_LABELSENTRY
DESCRIPTOR.message_types_by_name['Federation'] = _FEDERATION
DESCRIPTOR.message_types_by_name['FederationSecuritySettings'] = _FEDERATIONSECURITYSETTINGS
DESCRIPTOR.enum_types_by_name['BindingType'] = _BINDINGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Federation = _reflection.GeneratedProtocolMessageType('Federation', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FEDERATION_LABELSENTRY,
    '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.Federation.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _FEDERATION,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.Federation)
  })
_sym_db.RegisterMessage(Federation)
_sym_db.RegisterMessage(Federation.LabelsEntry)

FederationSecuritySettings = _reflection.GeneratedProtocolMessageType('FederationSecuritySettings', (_message.Message,), {
  'DESCRIPTOR' : _FEDERATIONSECURITYSETTINGS,
  '__module__' : 'yandex.cloud.organizationmanager.v1.saml.federation_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings)
  })
_sym_db.RegisterMessage(FederationSecuritySettings)


DESCRIPTOR._options = None
_FEDERATION_LABELSENTRY._options = None
_FEDERATION.fields_by_name['id']._options = None
_FEDERATION.fields_by_name['name']._options = None
_FEDERATION.fields_by_name['description']._options = None
_FEDERATION.fields_by_name['cookie_max_age']._options = None
_FEDERATION.fields_by_name['issuer']._options = None
_FEDERATION.fields_by_name['sso_url']._options = None
# @@protoc_insertion_point(module_scope)
